@@ -71,7 +71,8 @@ class DataTable(WidgetWrapper):
                     // jp-OutputArea-output *
                     let ptr = el;
                     while (!ptr.parent().hasClass("jp-Cell-outputArea")) {
-                        ptr.css('overflow-x', 'scroll');
+                        ptr.css('overflow-x', 'auto');
+                        ptr.css('margin', '0px');
                         ptr = ptr.parent();
                     }
 
